# pilton

[![DOI](https://zenodo.org/badge/68617930.svg)](https://zenodo.org/badge/latestdoi/68617930)

High-energy astrophysics software commonly uses [HEAdas Parameter Interface Library, PIL](https://heasarc.nasa.gov/lheasoft/headas/pil/).
This package provides python interface to the PIL-enabled tools 
